==> igniteui-react-charts-16.6.8.tgz: package/ES5/ForceIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ForceIndexIndicatorStrategy } from "./ForceIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var ForceIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(ForceIndexIndicator, _super);
    function ForceIndexIndicator() {
        var _this = _super.call(this) || this;
        _this.pd = 1;
        return _this;
    }
    ForceIndexIndicator.prototype.get_p5 = function () {
        return new ForceIndexIndicatorStrategy();
    };
    Object.defineProperty(ForceIndexIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    ForceIndexIndicator.prototype.get_qi = function () {
        return ForceIndexIndicator.$;
    };
    Object.defineProperty(ForceIndexIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForceIndexIndicator.prototype, "qq", {
        get: function () {
            return typeGetValue(this.c(ForceIndexIndicator.qr));
        },
        set: function (a) {
            this.h(ForceIndexIndicator.qr, a);
        },
        enumerable: true,
        configurable: true
    });
    ForceIndexIndicator.prototype.qb = function () {
        return this.qq;
    };
    ForceIndexIndicator.prototype.qk = function (a) {
        this.qq = a;
    };
    ForceIndexIndicator.$t = markType(ForceIndexIndicator, 'ForceIndexIndicator', StrategyBasedIndicator.$);
    ForceIndexIndicator.qr = StrategyBasedIndicator.qn(0, ForceIndexIndicator.$);
    return ForceIndexIndicator;
}(StrategyBasedIndicator));
export { ForceIndexIndicator };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/ForceIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ForceIndexIndicatorStrategy } from "./ForceIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var ForceIndexIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(ForceIndexIndicator, _super);
    function ForceIndexIndicator() {
        var _this = _super.call(this) || this;
        _this.pk = 1;
        return _this;
    }
    ForceIndexIndicator.prototype.get_qc = function () {
        return new ForceIndexIndicatorStrategy();
    };
    Object.defineProperty(ForceIndexIndicator.prototype, "qc", {
        get: function () {
            return this.get_qc();
        },
        enumerable: true,
        configurable: true
    });
    ForceIndexIndicator.prototype.get_qp = function () {
        return ForceIndexIndicator.$;
    };
    Object.defineProperty(ForceIndexIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForceIndexIndicator.prototype, "qx", {
        get: function () {
            return typeGetValue(this.c(ForceIndexIndicator.qy));
        },
        set: function (a) {
            this.h(ForceIndexIndicator.qy, a);
        },
        enumerable: true,
        configurable: true
    });
    ForceIndexIndicator.prototype.qi = function () {
        return this.qx;
    };
    ForceIndexIndicator.prototype.qr = function (a) {
        this.qx = a;
    };
    ForceIndexIndicator.$t = markType(ForceIndexIndicator, 'ForceIndexIndicator', StrategyBasedIndicator.$);
    ForceIndexIndicator.qy = StrategyBasedIndicator.qu(0, ForceIndexIndicator.$);
    return ForceIndexIndicator;
}(StrategyBasedIndicator));
export { ForceIndexIndicator };
